@@ -192,27 +192,31 @@ scroll_to_iter (GtkSourceCompletion *completion,
 	GtkTreePath *path;
 	GtkTreeIter prev_iter = *iter;
 
-	/* If we want to scroll to the first proposal of a provider, it's better
-	 * to show the header too, if there is a header. */
+	path = gtk_tree_model_get_path (GTK_TREE_MODEL (completion->priv->model_proposals),
+					iter);
+
+	gtk_tree_view_scroll_to_cell (completion->priv->tree_view_proposals,
+				      path, NULL,
+				      FALSE, 0, 0);
+	gtk_tree_path_free (path);
+
 	if (gtk_source_completion_model_iter_previous (completion->priv->model_proposals, &prev_iter) &&
 	    gtk_source_completion_model_iter_is_header (completion->priv->model_proposals, &prev_iter))
 	{
+		/* If we want to scroll to the first proposal of a provider,
+		 * it's better to show the header too, if there is a header.
+		 * We first scroll to the proposal, and then to the
+		 * header, so we are sure that the proposal is visible.
+		 */
+
 		path = gtk_tree_model_get_path (GTK_TREE_MODEL (completion->priv->model_proposals),
 						&prev_iter);
-	}
-	else
-	{
-		path = gtk_tree_model_get_path (GTK_TREE_MODEL (completion->priv->model_proposals),
-						iter);
-	}
 
-	gtk_tree_view_scroll_to_cell (completion->priv->tree_view_proposals,
-				      path,
-				      NULL,
-				      FALSE,
-				      0,
-				      0);
-	gtk_tree_path_free (path);
+		gtk_tree_view_scroll_to_cell (completion->priv->tree_view_proposals,
+					      path, NULL,
+					      FALSE, 0, 0);
+		gtk_tree_path_free (path);
+	}
 }
 
 /* Returns %TRUE if a proposal is selected.
@@ -953,6 +957,7 @@ gtk_source_completion_move_page (GtkSourceCompletion *completion,
 	}
 
 	gtk_tree_view_set_model (completion->priv->tree_view_proposals, NULL);
+	gtk_tree_view_columns_autosize (completion->priv->tree_view_proposals);
 
 	gtk_source_completion_model_set_visible_providers (completion->priv->model_proposals,
 							   visible_providers);
@@ -1205,6 +1210,8 @@ update_completion (GtkSourceCompletion        *completion,
 
 	/* Create a new CompletionModel */
 	gtk_tree_view_set_model (completion->priv->tree_view_proposals, NULL);
+	gtk_tree_view_columns_autosize (completion->priv->tree_view_proposals);
+
 	replace_model (completion);
 
 	for (item = providers_copy; item != NULL; item = g_list_next (item))
@@ -1364,15 +1371,15 @@ populating_done (GtkSourceCompletion        *completion,
 
 	update_selection_label (completion);
 
-	if (!gtk_widget_get_visible (GTK_WIDGET (completion->priv->main_window)))
-	{
-		g_signal_emit (completion, signals[SHOW], 0);
-	}
-
 	if (!check_first_selected (completion))
 	{
 		update_window_position (completion);
 	}
+
+	if (!gtk_widget_get_visible (GTK_WIDGET (completion->priv->main_window)))
+	{
+		g_signal_emit (completion, signals[SHOW], 0);
+	}
 }
 
 static void
@@ -2146,10 +2153,10 @@ init_main_window (GtkSourceCompletion *completion,
 	                             WINDOW_WIDTH,
 	                             WINDOW_HEIGHT);
 
-	g_signal_connect_after (completion->priv->main_window,
-				"configure-event",
-				G_CALLBACK (gtk_source_completion_configure_event),
-				completion);
+	g_signal_connect (completion->priv->main_window,
+			  "configure-event",
+			  G_CALLBACK (gtk_source_completion_configure_event),
+			  completion);
 
 	g_signal_connect (completion->priv->main_window,
 			  "delete-event",
